/* $Id: areals.c,v 1.2 2010-09-09 12:09:57 jim Exp $
 *
 * This file is part of the VIRCAM Pipeline
 * Copyright (C) 2005 Cambridge Astronomy Survey Unit
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: jim $
 * $Date: 2010-09-09 12:09:57 $
 * $Revision: 1.2 $
 * $Name: not supported by cvs2svn $
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "imcore.h"
#include "util.h"
#include "floatmath.h"

/**@{*/

/*---------------------------------------------------------------------------*/
/**
    \ingroup cataloguemodules
    \brief Work out the areal profiles for an object
  
    \par Name:
        areals
    \par Purpose:
        Work out the areal profiles for an object
    \par Description:
        The pixel list for an object is used to define the areal profiles
	for that object and a given detection threshold.
    \par Language:
        C
    \param ap
        The input ap structure
    \param iareal
        The output areal profile array
    \returns
        Nothing
    \par QC headers:
        None
    \par DRS headers:
        None
    \author
        Jim Lewis, CASU
 */
/*---------------------------------------------------------------------------*/

extern void areals(ap_t *ap, int iareal[NAREAL]) {
    int i,nup,j,np;
    float t,thresh,fconst,offset;
    plstruct *plarray;

    /* Initialise some stuff */

    np = ap->npl_pix;
    plarray = ap->plarray;
    thresh = ap->thresh;
    fconst = ap->fconst;
    offset = ap->areal_offset;

    /* Zero the areal profile array */

    (void)memset(iareal,0,NAREAL*sizeof(int));

    /* Loop through the array and form the areal profiles */

    for (i = 0; i < np; i++) {
        t = plarray[i].z;
        if (t <= thresh) 
	    continue;
	nup = MIN(NAREAL,(int)(logf(t)*fconst - offset)+1);
	nup = MAX(1,nup);
	for (j = 0; j < nup; j++)
	    iareal[j]++;
    }
}

/**@}*/
		
/*

$Log: not supported by cvs2svn $
Revision 1.1  2005/09/13 13:25:27  jim
Initial entry after modifications to make cpl compliant


*/
